@@ -15,11 +15,11 @@
 #  limitations under the License.
 
 import sys
-from calculate.lib.cl_template import TemplateFormat
-from calculate.lib.utils.text import _u
-from calculate.lib.cl_lang import setLocalTranslate
+from ..cl_template import TemplateFormat
+from ..utils.text import _u
+from ..cl_lang import setLocalTranslate
 from collections import OrderedDict
-from calculate.lib.utils.tools import json_module
+from ..utils.tools import json_module
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
