@@ -827,7 +827,7 @@ def grepFile(filename, regexp, flags=0):
         return match.group()
     return ""
 
-def readFile(filename, encoding='utf-8', binary=False):
+def readFile(filename, *, encoding='utf-8', binary=False):
     """
     Прочитать целый файл или вернуть пустую строку в случае ошибки
     """
@@ -878,7 +878,7 @@ def readFileEx(filename, tailbyte=None, headbyte=None, grab=False):
     return b""
 
 
-def writeFile(filename, encoding='utf-8', binary=False):
+def writeFile(filename, *, encoding='utf-8', binary=False):
     """
     Открыть файл на запись и создать необходимые каталоги
     """
@@ -1664,8 +1664,8 @@ class RealFs(tools.GenericFs):
     def exists(self, fn):
         return path.lexists(self._path(fn))
 
-    def read(self, fn):
-        return readFile(self._path(fn))
+    def read(self, fn, *, encoding="UTF-8", binary=False):
+        return readFile(self._path(fn), encoding=encoding, binary=binary)
 
     def glob(self, dn):
         for fn in glob(self._path(dn)):
@@ -1674,8 +1674,8 @@ class RealFs(tools.GenericFs):
     def realpath(self, fn):
         return self.remove_prefix(path.realpath(fn))
 
-    def write(self, fn, data):
-        with writeFile(fn) as f:
+    def write(self, fn, data, *, encoding="UTF-8", binary=False):
+        with writeFile(fn, encoding=encoding, binary=binary) as f:
             f.write(data)
 
     def listdir(self, dn, fullpath=False):
