@@ -1076,8 +1076,8 @@ class SchemeBuilder():
             raise DeviceSchemeError(
                 _("Please select devices for partitions changing"))
         if self.lvm:
-            lvm_devices, lvm_sizes = zip(
-                *self.create_lvm_devices(volumes_factory))
+            lvm_devices, lvm_sizes = list(zip(
+                *self.create_lvm_devices(volumes_factory)))
             return volumes_factory.createLvmBuilder(
                 list(lvm_devices), self.vgname,
                 sum(lvm_sizes), extsize=self.extsize)
