@@ -574,7 +574,7 @@ class GenericFs(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def read(self, fn):
+    def read(self, fn, encoding="UTF-8", binary=False):
         pass
 
     @abstractmethod
@@ -586,7 +586,7 @@ class GenericFs(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def write(self, fn, data):
+    def write(self, fn, data, encoding="UTF-8", binary=False):
         pass
 
     @abstractmethod
